#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Mark HH & LL
    /// </summary>
    [Description("Mark HH & LL")]
    public class NinjaPriceAction : Indicator
    {
        #region Variables
        // Inputs with defaults
            private int strength		= 3;	// Default setting for Strength
			private int lookback		= 50;	// Default lookback period in Bars
			private int dtbstrength		= 15; 	// Default double top and double bottom strength
			private int textoffset		= 50;	// Default setting Text Offset
		
        // User defined variables (add any user defined variables below)
			private int barsback;
			private double prevhigh;
			private double prevlow;
			private double curhigh;
			private double curlow;
			private double offset;
			private double curATR;
			private double toffset;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
           
			if (CurrentBar < lookback) return;
									
			barsback = Swing(strength).SwingHighBar(0,2,lookback);
			if (barsback == -1) return; 
			prevhigh = Swing(strength).SwingHigh[barsback]; 
						
			barsback = Swing(strength).SwingHighBar(0,1,lookback);
			if (barsback == -1) return; 
			curhigh = Swing(strength).SwingHigh[barsback]; 
			
			curATR	= ATR(14)[barsback];	
			offset	= curATR * dtbstrength / 100;
			toffset = curATR * textoffset / 100;
			
			
			if (curhigh < prevhigh + offset && curhigh > prevhigh - offset)
				DrawText("DT"+CurrentBar,"DT",barsback, High[barsback] + toffset, Color.Gold);		
			else	
			if (curhigh > prevhigh)
				DrawText("HH"+CurrentBar,"HH",barsback, High[barsback] + toffset, Color.Green);
			else
				DrawText("LH"+CurrentBar,"LH",barsback, High[barsback] + toffset, Color.Red);
			
			
			barsback = Swing(strength).SwingLowBar(0,2,lookback);
			if (barsback == -1) return; 
			prevlow = Swing(strength).SwingLow[barsback]; 
						
			barsback = Swing(strength).SwingLowBar(0,1,lookback);
			if (barsback == -1) return; 
			curlow = Swing(strength).SwingLow[barsback];
			
			curATR	= ATR(14)[barsback];	
			offset	= curATR * dtbstrength / 100;
			toffset = curATR * textoffset / 100;

			
			if (curlow > prevlow - offset && curlow < prevlow + offset)
				DrawText("DB"+CurrentBar,"DB",barsback, Low[barsback] - toffset, Color.Gold);
			else
			if (curlow < prevlow)
				DrawText("LL"+CurrentBar,"LL",barsback, Low[barsback] - toffset, Color.Red);
			else
				DrawText("HL"+CurrentBar,"HL",barsback, Low[barsback] - toffset, Color.Green);
			
			
        }

        #region Properties

        [Description("Swing Strength")]
        [Category("Parameters")]
        public int Strength
        {
            get { return strength; }
            set { strength = Math.Max(1, value); }
        }
		
		[Description("Text Offset")]
        [Category("Parameters")]
        public int TextOffset
        {
            get { return textoffset; }
            set { textoffset = Math.Max(1, value); }
        }
		
		[Description("Bar Lookback Period")]
        [Category("Parameters")]
        public int Lookback
        {
            get { return lookback; }
            set { lookback = Math.Max(1, value); }
        }
		
		[Description("Double Top & Bottom Strength")]
        [Category("Parameters")]
        public int DTBStrength
        {
            get { return dtbstrength; }
            set { dtbstrength = Math.Max(1, value); }
        }
		
		
		
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private NinjaPriceAction[] cacheNinjaPriceAction = null;

        private static NinjaPriceAction checkNinjaPriceAction = new NinjaPriceAction();

        /// <summary>
        /// Mark HH & LL
        /// </summary>
        /// <returns></returns>
        public NinjaPriceAction NinjaPriceAction(int dTBStrength, int lookback, int strength, int textOffset)
        {
            return NinjaPriceAction(Input, dTBStrength, lookback, strength, textOffset);
        }

        /// <summary>
        /// Mark HH & LL
        /// </summary>
        /// <returns></returns>
        public NinjaPriceAction NinjaPriceAction(Data.IDataSeries input, int dTBStrength, int lookback, int strength, int textOffset)
        {
            checkNinjaPriceAction.DTBStrength = dTBStrength;
            dTBStrength = checkNinjaPriceAction.DTBStrength;
            checkNinjaPriceAction.Lookback = lookback;
            lookback = checkNinjaPriceAction.Lookback;
            checkNinjaPriceAction.Strength = strength;
            strength = checkNinjaPriceAction.Strength;
            checkNinjaPriceAction.TextOffset = textOffset;
            textOffset = checkNinjaPriceAction.TextOffset;

            if (cacheNinjaPriceAction != null)
                for (int idx = 0; idx < cacheNinjaPriceAction.Length; idx++)
                    if (cacheNinjaPriceAction[idx].DTBStrength == dTBStrength && cacheNinjaPriceAction[idx].Lookback == lookback && cacheNinjaPriceAction[idx].Strength == strength && cacheNinjaPriceAction[idx].TextOffset == textOffset && cacheNinjaPriceAction[idx].EqualsInput(input))
                        return cacheNinjaPriceAction[idx];

            NinjaPriceAction indicator = new NinjaPriceAction();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.DTBStrength = dTBStrength;
            indicator.Lookback = lookback;
            indicator.Strength = strength;
            indicator.TextOffset = textOffset;
            indicator.SetUp();

            NinjaPriceAction[] tmp = new NinjaPriceAction[cacheNinjaPriceAction == null ? 1 : cacheNinjaPriceAction.Length + 1];
            if (cacheNinjaPriceAction != null)
                cacheNinjaPriceAction.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheNinjaPriceAction = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Mark HH & LL
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.NinjaPriceAction NinjaPriceAction(int dTBStrength, int lookback, int strength, int textOffset)
        {
            return _indicator.NinjaPriceAction(Input, dTBStrength, lookback, strength, textOffset);
        }

        /// <summary>
        /// Mark HH & LL
        /// </summary>
        /// <returns></returns>
        public Indicator.NinjaPriceAction NinjaPriceAction(Data.IDataSeries input, int dTBStrength, int lookback, int strength, int textOffset)
        {
            return _indicator.NinjaPriceAction(input, dTBStrength, lookback, strength, textOffset);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Mark HH & LL
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.NinjaPriceAction NinjaPriceAction(int dTBStrength, int lookback, int strength, int textOffset)
        {
            return _indicator.NinjaPriceAction(Input, dTBStrength, lookback, strength, textOffset);
        }

        /// <summary>
        /// Mark HH & LL
        /// </summary>
        /// <returns></returns>
        public Indicator.NinjaPriceAction NinjaPriceAction(Data.IDataSeries input, int dTBStrength, int lookback, int strength, int textOffset)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.NinjaPriceAction(input, dTBStrength, lookback, strength, textOffset);
        }

    }
}
#endregion
